@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 
@@ -53,7 +53,6 @@ static Boolean apply_variations(const Game *game_details,const Board *board,
 				Variation *variation);
 static Boolean rewrite_variations(const Board *board,Variation *variation);
 static Boolean rewrite_moves(Board *board,Move *moves);
-static const char *piece_str(Piece piece);
 
 	/* The English SAN piece characters. These are
 	 * always used when building a FEN string, rather
@@ -192,7 +191,7 @@ is_FEN_piece(char c)
 }
 
 	/* Return the SAN letter associated with the given piece. */
-static char
+char
 SAN_piece_letter(Piece piece)
 {
     if(piece >= 0 && piece < NUM_PIECE_VALUES){
@@ -773,7 +772,7 @@ apply_move(Colour colour,Move *move_details, Board *board)
 	 * values.
 	 */
 static Boolean
-play_moves(Game *game_details, Board *board,Move *moves,unsigned max_depth)
+play_moves(Game *game_details, Board *board, Move *moves, unsigned max_depth)
 {   Boolean game_ok = TRUE;
     /* Force a match if we aren't looking for positional variations. */
     Boolean game_matches = GlobalState.positional_variations?FALSE:TRUE;
@@ -813,11 +812,12 @@ play_moves(Game *game_details, Board *board,Move *moves,unsigned max_depth)
 	       if(board->to_move == WHITE){
 		   board->move_number++;
 	       }
-	       if(GlobalState.add_ECO){
+	       if(GlobalState.add_ECO && !GlobalState.parsing_ECO_file){
+		   int half_moves = half_moves_played(board);
 		   EcoLog *entry = eco_matches(
 			   board->hash_value,
 			   game_details->cumulative_hash_value,
-			   half_moves_played(board));
+			   half_moves);
 		   if(entry != NULL){
 		       /* Consider keeping the match.
 		        * Try to avoid spurious matches which become
@@ -830,7 +830,7 @@ play_moves(Game *game_details, Board *board,Move *moves,unsigned max_depth)
 		       if(eco_match == NULL){
 			   eco_match = entry;
 		       }
-		       else{
+		       else {
 			   /* This logic prefers a longer match
 			    * to a shorter, irrespective of whether
 			    * either match is exact or not.
@@ -1059,7 +1059,7 @@ apply_eco_move_list(Game *game_details,unsigned *number_of_half_moves)
 
 
 	/* Return the string associated with the given piece. */
-static const char *
+const char *
 piece_str(Piece piece)
 {
     if(piece >= 0 && piece < NUM_PIECE_VALUES){
