@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 
@@ -30,3 +30,5 @@ Board *new_fen_board(const char *fen);
 void set_output_piece_characters(const char *letters);
 char coloured_piece_to_SAN_letter(Piece coloured_piece);
 void build_basic_EPD_string(const Board *board,char *fen);
+char SAN_piece_letter(Piece piece);
+const char *piece_str(Piece piece);
