@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 
@@ -39,8 +39,8 @@
 #include "output.h"
 #include "lists.h"
 
-#define CURRENT_VERSION "(v15.0)"
-#define URL "http://www.cs.ukc.ac.uk/people/staff/djb/pgn-extract/"
+#define CURRENT_VERSION "v16.0"
+#define URL "http://www.cs.kent.ac.uk/people/staff/djb/pgn-extract/"
 
 /* The prefix of the arguments allowed in an argsfile.
  * The full format is:
@@ -126,7 +126,7 @@ usage_and_exit(unsigned level)
       "      this option must precede the -t or -T options.",
       "-V -- don't include variations in the output. Ordinarily these are retained.",
       "-wwidth -- set width as an approximate line width for output.",
-      "-W[cm|epd|halg|lalg|san] -- specify the output format to use.",
+      "-W[cm|epd|halg|lalg|elalg|san] -- specify the output format to use.",
       "      Default is SAN.",
       "      -W means use the input format.",
       "      -Wcm is (a possibly obsolete) ChessMaster format.",
@@ -134,6 +134,7 @@ usage_and_exit(unsigned level)
       "      -Wsan[PNBRQK] for language specific output.",
       "      -Whalg is hyphenated long algebraic.",
       "      -Wlalg is long algebraic.",
+      "      -Welalg is enhanced long algebraic.",
       "-zendings -- the file endings contains the end positions of interest.",
       "-Z -- use the file virtual.tmp as an external hash table for duplicates.",
       "      Use when MallocOrDie messages occur with big datasets.",
@@ -154,7 +155,7 @@ usage_and_exit(unsigned level)
           "pgn-extract %s (%s): a Portable Game Notation (PGN) manipulator.\n",
           CURRENT_VERSION,__DATE__);
   fprintf(GlobalState.logfile,
-          "Copyright (C) 1994-2001 David J. Barnes (d.j.barnes@ukc.ac.uk)\n");
+          "Copyright (C) 1994-2005 David J. Barnes (d.j.barnes@kent.ac.uk)\n");
   fprintf(GlobalState.logfile,"%s\n\n",URL);
   fprintf(GlobalState.logfile,"Usage: pgn-extract [arguments] [file.pgn ...]\n");
   fprintf(GlobalState.logfile,"Partial list of arguments ");
@@ -376,7 +377,7 @@ classify_arg(const char *line)
      * An argument -ofile.pgn would be passed in as:
      *		'o' and "file.pgn".
      * A zero-length string for associated_value is not necessarily
-     * an error, e.g. -e has an optional following filenname.
+     * an error, e.g. -e has an optional following filename.
      * If the associated_value is to be used beyond this function,
      * it must be copied.
      */
@@ -657,6 +658,7 @@ process_argument(char arg_letter,const char *associated_value)
 
 	      if(sscanf(associated_value,"%u",&length) > 0){
 		  GlobalState.max_line_length = length;
+		  set_output_line_length(GlobalState.max_line_length);
 	      }
 	      else{
 		  fprintf(GlobalState.logfile,
