@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 
@@ -53,6 +53,14 @@ static int maximum_half_moves = ECO_HALF_MOVE_LIMIT;
 #define ECO_TABLE_SIZE 4096
 static EcoLog **EcoTable;
 
+/* Rate the quality of an ECO match.
+ * Currently unused.
+ */
+static int eco_match_quality(EcoLog* entry,
+		      HashCode current_hash_value,
+		      HashCode cumulative_hash_value,
+		      int half_moves_played);
+
 #if INCLUDE_UNUSED_FUNCTIONS
 static void
 dumpEcoTable(void)
@@ -229,6 +237,34 @@ save_eco_details(Game game_details,unsigned number_of_half_moves)
     }
 }
 
+/* Quality values for aspects of an ECO match.
+ * Currently unused.
+ */
+static int ECO_REQUIRED_HASH_VALUE = 1;
+static int ECO_HALF_MOVE_VALUE = 1;
+static int ECO_CUMULATIVE_HASH_VALUE = 0;
+
+/* Rate the quality of the given match.
+ * Currently unused.
+ */
+static int eco_match_quality(EcoLog* entry,
+		      HashCode current_hash_value,
+		      HashCode cumulative_hash_value,
+		      int half_moves_played)
+{
+    int quality = 0;
+    if(entry->required_hash_value == current_hash_value){
+	quality += ECO_REQUIRED_HASH_VALUE;
+	if(abs(half_moves_played - entry->half_moves) <= ECO_HALF_MOVE_LIMIT) {
+	    quality += ECO_HALF_MOVE_VALUE;
+	}
+	if(entry->cumulative_hash_value == cumulative_hash_value){
+	    quality += ECO_CUMULATIVE_HASH_VALUE;
+	}
+    }
+    return quality;
+}
+
 	/* Look in EcoTable for current_hash_value.
 	 * Use cumulative_hash_value to refine the match.
 	 * An exact match is preferable to a partial match.
