@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 #include <stdio.h>
@@ -158,7 +158,7 @@ report_details(FILE *outfp)
 
 	/* Check that terminating_result is consistent with
 	 * Tags[RESULT_TAG].  If the latter is missing, fill it
-	 * in from terminating_tag.
+	 * in from terminating_result.
 	 */
 static void
 check_result(char **Tags,const char *terminating_result)
@@ -230,23 +230,27 @@ ParseOptGameList(SourceFileType file_type)
 {   Move *move_list = NULL;
 
     while(ParseGame(&move_list)){
-	if(move_list != NULL){
-	    if(file_type == NORMALFILE){
-		DealWithGame(move_list);
-	    }
-	    else if(file_type == CHECKFILE){
-		DealWithGame(move_list);
-	    }
-	    else if(file_type == ECOFILE){
+	if(file_type == NORMALFILE){
+	    DealWithGame(move_list);
+	}
+	else if(file_type == CHECKFILE){
+	    DealWithGame(move_list);
+	}
+	else if(file_type == ECOFILE){
+	    if(move_list != NULL){
 		DealWithEcoLine(move_list);
 	    }
-	    else{
-		/* Unknown type. */
-		free_tags();
-		free_move_list(move_list);
+	    else {
+		fprintf(GlobalState.logfile,"ECO line with zero moves.\n");
+		report_details(GlobalState.logfile);
 	    }
-	    move_list = NULL;
 	}
+	else{
+	    /* Unknown type. */
+	    free_tags();
+	    free_move_list(move_list);
+	}
+	move_list = NULL;
 	setup_for_new_game();
     }
 }
@@ -301,13 +305,18 @@ ParseGame(Move **returned_move_list)
 	something_found = TRUE;
     }
     else{
-	/* @@@ Should we do anything (else) if something_found but
-	 * no move list?
+	/*
+	 * Workaround for games with zero moves.
+	 * Check the result for consistency with the tags, but then
+	 * there is no move to attach it to.
+	 * When outputting a game, the missing result in this case
+	 * will have to be supplied from the tags.
 	 */
-	free_tags();
+	check_result(Game_Header.Tags,result);
 	if(result != NULL){
 	    (void) free((void *)result);
 	}
+	*returned_move_list = NULL;
     }
     return Symbol != EOF_TOKEN;
 }
@@ -761,6 +770,7 @@ DealWithGame(Move *move_list)
 
     /* Update the count of how many games handled. */
     GlobalState.num_games_processed++;
+
     /* Fill in the information currently known. */
     current_game.tags = Game_Header.Tags;
     current_game.tags_length = Game_Header.header_tags_length;
@@ -772,7 +782,7 @@ DealWithGame(Move *move_list)
     /* Determine whether or not this game is wanted, on the
      * basis of the various selection criteria available.
      */
-  
+    
     /*
      * apply_move_list checks out the moves.
      * If it returns TRUE as a match, it will also fill in the
