@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 #include <stdio.h>
@@ -72,6 +72,7 @@ StateInfo GlobalState = {
     FALSE,                /* suppress_originals (-U) */
     FALSE,                /* check_tags */
     FALSE,                /* add_ECO (-e) */
+    FALSE,                /* parsing_ECO_file (-e) */
     DONT_DIVIDE,          /* ECO_level (-E) */
     SAN,                  /* output_format (-W) */
     MAX_LINE_LENGTH,      /* max_line_length (-w) */
@@ -101,6 +102,7 @@ init_default_global_state(void)
 {
     GlobalState.outputfile = stdout;
     GlobalState.logfile = stderr;
+    set_output_line_length(GlobalState.max_line_length);
 }
 
 int
@@ -298,13 +300,10 @@ main(int argc, char *argv[])
     if(GlobalState.add_ECO){
         /* Read in a list of ECO lines in order to classify the games. */
         if(open_eco_file(GlobalState.eco_file)){
-            /* Temporarily turn off ECO lookup, otherwise each ECO line
-             * is looked up in the table being built!
-             */
-            GlobalState.add_ECO = FALSE;
+            /* Indicate that the ECO file is currently being parsed. */
+            GlobalState.parsing_ECO_file = TRUE;
             yyparse(ECOFILE);
-            /* Turn ECO lookup back on. */
-            GlobalState.add_ECO = TRUE;
+            GlobalState.parsing_ECO_file = FALSE;
         }
         else{
             fprintf(GlobalState.logfile,"Unable to open the ECO file %s.\n",
