@@ -1,6 +1,6 @@
 /*
  *  Program: pgn-extract: a Portable Game Notation (PGN) extractor.
- *  Copyright (C) 1994-2001 David Barnes
+ *  Copyright (C) 1994-2005 David Barnes
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
  *  the Free Software Foundation; either version 1, or (at your option)
@@ -15,8 +15,8 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  David Barnes may be contacted as D.J.Barnes@ukc.ac.uk
- *  http://www.cs.ukc.ac.uk/people/staff/djb/
+ *  David Barnes may be contacted as D.J.Barnes@kent.ac.uk
+ *  http://www.cs.kent.ac.uk/people/staff/djb/
  *
  */
 
@@ -29,8 +29,10 @@
      *	   CM: Chess Master input format.
      *     LALG: Long-algebraic, e.g. e2e4.
      *     HALG: Hyphenated long-algebraic, e.g. e2-e4.
+     *     ELALG: Enhanced long-algebraic. Includes piece names, e.g. Ng1f3,
+     *            and en-passant notation.
      */
-typedef enum { SOURCE, SAN, EPD, CM, LALG, HALG } OutputFormat;
+typedef enum { SOURCE, SAN, EPD, CM, LALG, HALG, ELALG } OutputFormat;
 
     /* Define a type to specify whether a move gives check, checkmate,
      * or nocheck.
@@ -189,6 +191,8 @@ typedef struct {
     Boolean check_tags;
     /* Whether to add ECO codes. */
     Boolean add_ECO;
+    /* Whether an ECO file is currently being parsed. */
+    Boolean parsing_ECO_file;
     /* Which level to divide the output. */
     EcoDivision ECO_level;
     /* What form to write the output in. */
